#[non_exhaustive]pub struct ModelTurn {
pub message_id: Option<String>,
pub choice: OneOrMany<AssistantContent>,
pub usage: Usage,
pub executable_tool_names: BTreeSet<String>,
pub allowed_tool_names: BTreeSet<String>,
}Expand description
A completed model turn fed back to AgentRun::model_response.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message_id: Option<String>Provider-assigned assistant message ID, when available.
choice: OneOrMany<AssistantContent>The assistant content returned by the model.
usage: UsageToken usage reported by the provider for this completion request.
executable_tool_names: BTreeSet<String>Executable Rig tools advertised to the provider for this turn.
allowed_tool_names: BTreeSet<String>Tools allowed by the active ToolChoice for this turn.
Implementations