pub struct FinalResponse { /* private fields */ }Implementations
Sourceimpl FinalResponse
impl FinalResponse
pub fn empty() -> Self
pub fn new( content: OneOrMany<AssistantContent>, aggregated_usage: Usage, history: Option<Vec<Message>>, ) -> Self
Sourcepub fn content(&self) -> &OneOrMany<AssistantContent>
pub fn content(&self) -> &OneOrMany<AssistantContent>
Returns the structured assistant content for the final turn.
Sourcepub fn assistant_content(&self) -> &OneOrMany<AssistantContent>
pub fn assistant_content(&self) -> &OneOrMany<AssistantContent>
Returns the structured assistant content for the final turn.
pub fn usage(&self) -> Usage
Sourcepub fn completion_calls(&self) -> &[CompletionCall]
pub fn completion_calls(&self) -> &[CompletionCall]
Returns successfully completed completion requests made by this agent stream, with usage when available.
Each entry represents one provider completion request. When present,
usage is a whole-request provider snapshot, not incremental usage per
streamed token. Streaming providers may omit usage for some calls; those
calls have an entry with None usage.
pub fn history(&self) -> Option<&[Message]>