pub struct AudioGenerationRequestBuilder { /* private fields */ }Available on crate feature
audio only.Expand description
Builds a speech request for a text and voice. The speed defaults to 1.0.
Implementations
Sourceimpl AudioGenerationRequestBuilder
impl AudioGenerationRequestBuilder
Sourcepub fn new(text: impl Into<String>, voice: impl Into<String>) -> Self
pub fn new(text: impl Into<String>, voice: impl Into<String>) -> Self
A request to speak text in voice.
Sourcepub fn additional_params(self, params: impl Into<Option<Value>>) -> Self
pub fn additional_params(self, params: impl Into<Option<Value>>) -> Self
Merges provider-specific parameters over earlier ones, key by key for
JSON objects; None clears existing parameters.
Sourcepub fn build(self) -> AudioGenerationRequest
pub fn build(self) -> AudioGenerationRequest
Builds the audio generation request.