#[non_exhaustive]pub struct CacheSupport {
pub retention: Vec<CacheRetention>,
}Expand description
The cache retentions a model honours.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.retention: Vec<CacheRetention>The CacheRetention values the model honours. Empty when the
catalog does not know, in which case nothing is refused.
Implementations
Sourceimpl CacheSupport
impl CacheSupport
Sourcepub fn refusal(&self, cache: &CacheRetention) -> Option<String>
pub fn refusal(&self, cache: &CacheRetention) -> Option<String>
Why the model cannot honour cache, or None when it can or the
catalog does not know.