pub struct ToolSchema {
pub name: String,
pub context: Value,
pub embedding_docs: Vec<String>,
}Expand description
Tool name, serialized context, and text descriptions for embedding-based retrieval.
Fields
name: Stringcontext: Valueembedding_docs: Vec<String>Implementations
Sourceimpl ToolSchema
impl ToolSchema
Sourcepub fn try_from<T>(tool: &T) -> Result<Self, EmbedError>where
T: PortableToolEmbedding,
pub fn try_from<T>(tool: &T) -> Result<Self, EmbedError>where
T: PortableToolEmbedding,
Captures a tool’s name, context, and embedding descriptions. Returns an error if context serialization fails.
use rig_core::{embeddings::{ToolSchema, EmbedError}, tool::PortableToolEmbedding};
fn schema(tool: &impl PortableToolEmbedding) -> Result<ToolSchema, EmbedError> {
ToolSchema::try_from(tool)
}Trait Implementations
Sourceimpl Clone for ToolSchema
impl Clone for ToolSchema
Sourceimpl Default for ToolSchema
impl Default for ToolSchema
Sourceimpl Embed for ToolSchema
impl Embed for ToolSchema
Sourcefn embed(&self, embedder: &mut TextEmbedder) -> Result<(), EmbedError>
fn embed(&self, embedder: &mut TextEmbedder) -> Result<(), EmbedError>
Append all text fragments that should be embedded for this value.
impl Eq for ToolSchema
Sourceimpl PartialEq for ToolSchema
impl PartialEq for ToolSchema
Sourceimpl Serialize for ToolSchema
impl Serialize for ToolSchema
impl StructuralPartialEq for ToolSchema