Judgment

Trait Judgment 

pub trait Judgment {
    // Required method
    fn passes(&self) -> bool;
}
Available on crate feature experimental only.
A helper trait for LlmJudgeMetric. Types that implement Judgment generally have a very standard way of either passing or failing. As such, this can be enforced as a trait.

Required Methods

fn passes(&self) -> bool

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors