pub struct MessagesDecoder { /* private fields */ }Expand description
Decodes Messages replies, a whole message or a stream of events.
content_block_stop states a block complete; a stop reason states every
block still open complete, but a call whose input is not yet JSON.
Implementations