pub struct AzureExt { /* private fields */ }Trait Implementations
Sourceimpl<H> Capabilities<H> for AzureExt
impl<H> Capabilities<H> for AzureExt
Sourcetype Completion = Capable<CompletionModel<H>>
type Completion = Capable<CompletionModel<H>>
Completion model capability marker.
Sourcetype Embeddings = Capable<EmbeddingModel<H>>
type Embeddings = Capable<EmbeddingModel<H>>
Embedding model capability marker.
Sourcetype Transcription = Capable<TranscriptionModel<H>>
type Transcription = Capable<TranscriptionModel<H>>
Audio transcription model capability marker.
Sourcetype ModelListing = Nothing
type ModelListing = Nothing
Model listing capability marker.
Sourcetype ImageGeneration = Nothing
type ImageGeneration = Nothing
Available on crate feature
image only.Image generation model capability marker.
Sourcetype AudioGeneration = Capable<AudioGenerationModel<H>>
type AudioGeneration = Capable<AudioGenerationModel<H>>
Available on crate feature
audio only.Audio generation model capability marker.
Sourceimpl Provider for AzureExt
impl Provider for AzureExt
Sourceconst VERIFY_PATH: &'static str = ""
const VERIFY_PATH: &'static str = ""
Verifying Azure auth without consuming tokens is not supported
Sourcetype Builder = AzureExtBuilder
type Builder = AzureExtBuilder
The builder type that constructs this provider extension.
This associates extensions with their builders for type inference.