pub struct ChatDecoder { /* private fields */ }Expand description
Decodes native chat replies, a whole reply or a stream of events. An
*-end event states its block complete, and message-end states every
block still open complete, but a call whose arguments are not JSON.