pub struct DoublewordExtBuilder;Trait Implementations
Sourceimpl Clone for DoublewordExtBuilder
impl Clone for DoublewordExtBuilder
Sourcefn clone(&self) -> DoublewordExtBuilder
fn clone(&self) -> DoublewordExtBuilder
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DoublewordExtBuilder
Sourceimpl Debug for DoublewordExtBuilder
impl Debug for DoublewordExtBuilder
Sourceimpl Default for DoublewordExtBuilder
impl Default for DoublewordExtBuilder
Sourcefn default() -> DoublewordExtBuilder
fn default() -> DoublewordExtBuilder
Returns the “default value” for a type. Read more
Sourceimpl ProviderBuilder for DoublewordExtBuilder
impl ProviderBuilder for DoublewordExtBuilder
Sourcetype Extension<H> = DoublewordExt
where
H: HttpClientExt
type Extension<H> = DoublewordExt where H: HttpClientExt
Provider extension type built for a concrete HTTP backend.
Sourcetype ApiKey = BearerAuth
type ApiKey = BearerAuth
API key input type accepted by the provider’s client builder.
Sourcefn build<H>(
_builder: &ClientBuilder<Self, Self::ApiKey, H>,
) -> Result<Self::Extension<H>>where
H: HttpClientExt,
fn build<H>(
_builder: &ClientBuilder<Self, Self::ApiKey, H>,
) -> Result<Self::Extension<H>>where
H: HttpClientExt,
Build the provider extension from the client builder configuration.
Sourcefn finish<H>(
&self,
builder: ClientBuilder<Self, Self::ApiKey, H>,
) -> Result<ClientBuilder<Self, Self::ApiKey, H>>
fn finish<H>( &self, builder: ClientBuilder<Self, Self::ApiKey, H>, ) -> Result<ClientBuilder<Self, Self::ApiKey, H>>
This method can be used to customize the fields of
builder before it is used to create
a client. For example, adding default headersAuto Trait Implementations
impl Freeze for DoublewordExtBuilder
impl RefUnwindSafe for DoublewordExtBuilder
impl Send for DoublewordExtBuilder
impl Sync for DoublewordExtBuilder
impl Unpin for DoublewordExtBuilder
impl UnsafeUnpin for DoublewordExtBuilder
impl UnwindSafe for DoublewordExtBuilder