pub struct OpenAIResponsesExtBuilder;Trait Implementations
Sourceimpl Clone for OpenAIResponsesExtBuilder
impl Clone for OpenAIResponsesExtBuilder
Sourcefn clone(&self) -> OpenAIResponsesExtBuilder
fn clone(&self) -> OpenAIResponsesExtBuilder
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OpenAIResponsesExtBuilder
impl Debug for OpenAIResponsesExtBuilder
Sourceimpl Default for OpenAIResponsesExtBuilder
impl Default for OpenAIResponsesExtBuilder
Sourcefn default() -> OpenAIResponsesExtBuilder
fn default() -> OpenAIResponsesExtBuilder
Returns the “default value” for a type. Read more
Sourceimpl ProviderBuilder for OpenAIResponsesExtBuilder
impl ProviderBuilder for OpenAIResponsesExtBuilder
Sourcetype Extension<H> = OpenAIResponsesExt
where
H: HttpClientExt
type Extension<H> = OpenAIResponsesExt where H: HttpClientExt
Provider extension type built for a concrete HTTP backend.
Sourcetype ApiKey = BearerAuth
type ApiKey = BearerAuth
API key input type accepted by the provider’s client builder.
Sourcefn build<H>(
_builder: &ClientBuilder<Self, Self::ApiKey, H>,
) -> Result<Self::Extension<H>>where
H: HttpClientExt,
fn build<H>(
_builder: &ClientBuilder<Self, Self::ApiKey, H>,
) -> Result<Self::Extension<H>>where
H: HttpClientExt,
Build the provider extension from the client builder configuration.
Sourcefn finish<H>(
&self,
builder: ClientBuilder<Self, Self::ApiKey, H>,
) -> Result<ClientBuilder<Self, Self::ApiKey, H>>
fn finish<H>( &self, builder: ClientBuilder<Self, Self::ApiKey, H>, ) -> Result<ClientBuilder<Self, Self::ApiKey, H>>
This method can be used to customize the fields of
builder before it is used to create
a client. For example, adding default headersimpl Copy for OpenAIResponsesExtBuilder