pub enum AllowedToolsMode {
Auto,
Required,
}Expand description
Constrains how the model may use the tools listed in
ToolChoiceDefinition::AllowedTools.
Variants
Auto
The model may call one of the allowed tools or answer directly.
Required
The model must call one of the allowed tools.