pub struct ResponsesToolDefinition {
pub kind: String,
pub name: String,
pub parameters: Value,
pub strict: bool,
pub description: String,
pub config: Map<String, Value>,
}Expand description
The definition of a tool response, repurposed for OpenAI’s Responses API.
Fields
kind: StringThe type of tool.
name: StringTool name
parameters: ValueParameters - this should be a JSON schema. Tools should additionally ensure an “additionalParameters” field has been added with the value set to false, as this is required if using OpenAI’s strict mode (enabled by default).
strict: boolWhether to use strict mode. Enabled by default as it allows for improved efficiency.
description: StringTool description.
config: Map<String, Value>Additional provider-specific configuration for hosted tools.
Implementations
Sourceimpl ResponsesToolDefinition
impl ResponsesToolDefinition
Sourcepub fn function(
name: impl Into<String>,
description: impl Into<String>,
parameters: Value,
) -> Self
pub fn function( name: impl Into<String>, description: impl Into<String>, parameters: Value, ) -> Self
Creates a function tool definition.
Sourcepub fn hosted(kind: impl Into<String>) -> Self
pub fn hosted(kind: impl Into<String>) -> Self
Creates a hosted tool definition for an arbitrary hosted tool type.
Sourcepub fn web_search() -> Self
pub fn web_search() -> Self
Creates a hosted web_search tool definition.
Sourcepub fn file_search() -> Self
pub fn file_search() -> Self
Creates a hosted file_search tool definition.
Sourcepub fn computer_use() -> Self
pub fn computer_use() -> Self
Creates a hosted computer_use tool definition.
Sourcepub fn with_config(self, key: impl Into<String>, value: Value) -> Self
pub fn with_config(self, key: impl Into<String>, value: Value) -> Self
Adds hosted-tool configuration fields.