pub struct ResponsesWebSocketSessionBuilder { /* private fields */ }Available on crate feature
websocket only.Expand description
A builder for an OpenAI Responses WebSocket session.
The default builder applies a 30 second connection timeout and leaves the per-event timeout disabled.
Implementations
Sourceimpl ResponsesWebSocketSessionBuilder
impl ResponsesWebSocketSessionBuilder
Sourcepub fn connect_timeout(self, timeout: Duration) -> Self
pub fn connect_timeout(self, timeout: Duration) -> Self
Sets the timeout for establishing the websocket connection.
Sourcepub fn without_connect_timeout(self) -> Self
pub fn without_connect_timeout(self) -> Self
Disables the websocket connection timeout.
Sourcepub fn event_timeout(self, timeout: Duration) -> Self
pub fn event_timeout(self, timeout: Duration) -> Self
Sets the timeout for waiting on the next websocket event.
Sourcepub fn without_event_timeout(self) -> Self
pub fn without_event_timeout(self) -> Self
Disables the websocket event timeout.
Sourceimpl ResponsesWebSocketSessionBuilder
impl ResponsesWebSocketSessionBuilder
Sourcepub async fn connect(self) -> Result<ResponsesWebSocketSession, ProviderError>
Available on crate feature tungstenite only.
pub async fn connect(self) -> Result<ResponsesWebSocketSession, ProviderError>
tungstenite only.Open a session over the bundled tungstenite backend with the configured timeouts. Return handshake construction, transport, or provider errors.
Sourcepub async fn connect_with<W>(
self,
backend: &W,
) -> Result<ResponsesWebSocketSession, ProviderError>where
W: WebSocketClientExt,
pub async fn connect_with<W>(
self,
backend: &W,
) -> Result<ResponsesWebSocketSession, ProviderError>where
W: WebSocketClientExt,
Open a session over backend with the configured timeouts.
Return handshake construction, transport, or provider errors.