pub struct ResponseImage {
pub image_url: ImageUrl,
}Expand description
An image emitted by an image-generation model. OpenRouter returns generated images
out-of-band from content, as a sibling images array on the assistant message.
Each entry mirrors the request-side image_url content part structure.
Fields
image_url: ImageUrlTrait Implementations
Sourceimpl Clone for ResponseImage
impl Clone for ResponseImage
Sourcefn clone(&self) -> ResponseImage
fn clone(&self) -> ResponseImage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResponseImage
impl Debug for ResponseImage
Sourceimpl<'de> Deserialize<'de> for ResponseImage
impl<'de> Deserialize<'de> for ResponseImage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ResponseImage
impl PartialEq for ResponseImage
Sourcefn eq(&self, other: &ResponseImage) -> bool
fn eq(&self, other: &ResponseImage) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ResponseImage
impl Serialize for ResponseImage
impl StructuralPartialEq for ResponseImage