Module telemetry

Module telemetry 

This module primarily concerns being able to orchestrate telemetry across a given pipeline or workflow. This includes tracing, being able to send traces to an OpenTelemetry collector, setting up your agents with the correct tracing style so you can emit the right traces for platforms like Langfuse, and more.

Traits

ProviderRequestExt
Provider request metadata used to populate GenAI telemetry spans.
ProviderResponseExt
Provider response metadata used to populate GenAI telemetry spans.
SpanCombinator
A trait designed specifically to be used with Spans for the purpose of recording telemetry. Implemented for tracing::Span to record GenAI semantic convention fields.