pub struct Divergence {
pub index: usize,
pub expected: Option<Observation>,
pub actual: Option<Observation>,
}Available on crate feature
test-utils only.Expand description
Where two traces first disagree on a semantic field.
Fields
index: usizeThe index of the first observation that differs (or the length of the shorter trace when one is a prefix of the other).
expected: Option<Observation>The expected fact, if any.
actual: Option<Observation>The actual fact, if any.