pub struct MockCompletionModel { /* private fields */ }Available on crate feature
test-utils only.Expand description
A cloneable scripted CompletionModel for tests.
Each completion or stream call consumes exactly one scripted turn. If no turn
is available, the model returns CompletionError::ProviderError with a
clear message instead of repeating previous responses.
Implementations
Sourceimpl MockCompletionModel
impl MockCompletionModel
Sourcepub fn new(turns: impl IntoIterator<Item = MockTurn>) -> Self
pub fn new(turns: impl IntoIterator<Item = MockTurn>) -> Self
Create a mock model from scripted non-streaming turns.
Sourcepub fn text(text: impl Into<String>) -> Self
pub fn text(text: impl Into<String>) -> Self
Create a mock model that returns one text completion.
Sourcepub fn from_turns(turns: impl IntoIterator<Item = MockTurn>) -> Self
pub fn from_turns(turns: impl IntoIterator<Item = MockTurn>) -> Self
Create a mock model from scripted non-streaming turns.
Sourcepub fn from_stream_turns(
stream_turns: impl IntoIterator<Item = impl IntoIterator<Item = MockStreamEvent>>,
) -> Self
pub fn from_stream_turns( stream_turns: impl IntoIterator<Item = impl IntoIterator<Item = MockStreamEvent>>, ) -> Self
Create a mock model from scripted streaming turns.
Sourcepub fn requests(&self) -> Vec<CompletionRequest>
pub fn requests(&self) -> Vec<CompletionRequest>
Return cloned requests received by this model.
Sourcepub fn request_count(&self) -> usize
pub fn request_count(&self) -> usize
Return the number of requests received by this model.