pub struct MockToolIndex { /* private fields */ }Available on crate feature
test-utils only.Expand description
A vector index that returns a predefined list of tool IDs from top_n_ids.
Implementations
Sourceimpl MockToolIndex
impl MockToolIndex
Sourcepub fn new(tool_ids: impl IntoIterator<Item = impl Into<String>>) -> Self
pub fn new(tool_ids: impl IntoIterator<Item = impl Into<String>>) -> Self
Create a tool index that returns the given IDs in order.