pub struct ToolSetBuilder { /* private fields */ }Expand description
Builder for constructing a ToolSet with static and dynamic tools.
Implementations
Sourceimpl ToolSetBuilder
impl ToolSetBuilder
Sourcepub fn static_tool(self, tool: impl ToolDyn + 'static) -> Self
pub fn static_tool(self, tool: impl ToolDyn + 'static) -> Self
Add a regular tool that is always available when the set is used.
Sourcepub fn dynamic_tool(self, tool: impl ToolEmbeddingDyn + 'static) -> Self
pub fn dynamic_tool(self, tool: impl ToolEmbeddingDyn + 'static) -> Self
Add a tool that can be represented as embeddings for dynamic retrieval.