pub fn not_executed(call: &ToolCall) -> UserContentExpand description
The result of a call the run did not execute because a call beside it was invalid.
pub fn not_executed(call: &ToolCall) -> UserContentThe result of a call the run did not execute because a call beside it was invalid.