pub fn tool_result_output(
call: CallId,
name: ToolName,
output: ToolOutput,
) -> UserContentExpand description
Shape a canonical real tool output as a tool result without reparsing text.
pub fn tool_result_output(
call: CallId,
name: ToolName,
output: ToolOutput,
) -> UserContentShape a canonical real tool output as a tool result without reparsing text.