#[non_exhaustive]pub struct WireSpan {
pub start: u64,
pub end: u64,
pub unit: SpanUnit,
pub quoted: Option<String>,
}Expand description
Offsets into a text block as the provider counts them.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.start: u64The first offset.
end: u64The offset after the last.
unit: SpanUnitWhat the offsets count.
quoted: Option<String>The text the provider says the span covers, which the resolved span must match.
Implementations