PromptResponse

Struct PromptResponse 

#[non_exhaustive]
pub struct PromptResponse { pub output: String, pub usage: Usage, pub completion_calls: Vec<CompletionCall>, pub messages: Option<Vec<Message>>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
output: Stringusage: Usagecompletion_calls: Vec<CompletionCall>

Successfully completed completion requests made by this agent run, with token usage when available.

usage remains the aggregate across the whole run. Use the last entry’s usage, when present, to inspect the final completion request’s prompt/context length. If a provider does not report token usage, its entry contains None.

messages: Option<Vec<Message>>

Implementations

Source

impl PromptResponse

pub fn new(output: impl Into<String>, usage: Usage) -> Self

pub fn with_messages(self, messages: Vec<Message>) -> Self

pub fn with_completion_calls( self, completion_calls: Vec<CompletionCall>, ) -> Self

Attach completion call details to this response.

pub fn completion_calls(&self) -> &[CompletionCall]

Returns successfully completed completion requests made by this agent run, with token usage when available.

If a provider does not report token usage, its entry contains None.