pub struct WithBuilderTools { /* private fields */ }Expand description
Typestate indicating tools are being configured via the builder API.
In this state, you can continue adding tools via .tool(), .tools(),
.dynamic_tools(), etc. When .build() is called, a new ToolServer
will be created with all the configured tools.