pub trait Provider: Sized {
type Builder: ProviderBuilder;
const VERIFY_PATH: &'static str;
// Provided methods
fn build_uri(
&self,
base_url: &str,
path: &str,
_transport: Transport,
) -> String { ... }
fn with_custom(&self, req: Builder) -> Result<Builder> { ... }
}Expand description
An API provider extension, this abstracts over extensions which may be used in conjunction with
the Client<Ext, H> struct to define the behavior of a provider with respect to networking,
auth, instantiating models
Required Associated Constants
Sourceconst VERIFY_PATH: &'static str
const VERIFY_PATH: &'static str
Provider endpoint used by VerifyClient to validate credentials.
Required Associated Types
Sourcetype Builder: ProviderBuilder
type Builder: ProviderBuilder
The builder type that constructs this provider extension. This associates extensions with their builders for type inference.
Provided Methods
Sourcefn build_uri(&self, base_url: &str, path: &str, _transport: Transport) -> String
fn build_uri(&self, base_url: &str, path: &str, _transport: Transport) -> String
Build a complete request URI for the given base URL, provider path, and transport.
Sourcefn with_custom(&self, req: Builder) -> Result<Builder>
fn with_custom(&self, req: Builder) -> Result<Builder>
Apply provider-specific request customization before sending.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".