pub enum PromptError {
CompletionError(CompletionError),
ToolError(ToolSetError),
ToolServerError(Box<ToolServerError>),
MaxTurnsError {
max_turns: usize,
chat_history: Box<Vec<Message>>,
prompt: Box<Message>,
},
PromptCancelled {
chat_history: Vec<Message>,
reason: String,
},
UnknownToolCall {
tool_name: String,
available_tools: Vec<String>,
allowed_tools: Vec<String>,
chat_history: Box<Vec<Message>>,
},
}Expand description
Prompt errors
Variants
CompletionError(CompletionError)
Something went wrong with the completion
ToolError(ToolSetError)
There was an error while using a tool
ToolServerError(Box<ToolServerError>)
There was an issue while executing a tool on a tool server
MaxTurnsError
The LLM tried to call too many tools during a multi-turn conversation.
To fix this, you may either need to lower the amount of tools your model has access to (and then create other agents to share the tool load)
or increase the amount of turns given in .multi_turn().
PromptCancelled
A prompting loop was cancelled.
UnknownToolCall
The model emitted a structured tool call for a tool Rig did not allow for the current turn.