pub struct EmbeddingResponse {
pub embeddings: Vec<Embedding>,
pub usage: Usage,
}Expand description
Response from an embedding request containing the embeddings and token usage.
Fields
embeddings: Vec<Embedding>The embeddings returned by the provider, one per input text.
usage: UsageToken usage for this embedding request.