pub struct MockTurn { /* private fields */ }Available on crate feature
test-utils only.Expand description
A scripted non-streaming mock completion turn.
Implementations
Sourceimpl MockTurn
impl MockTurn
Sourcepub fn tool_call(
id: impl Into<String>,
name: impl Into<String>,
arguments: Value,
) -> Self
pub fn tool_call( id: impl Into<String>, name: impl Into<String>, arguments: Value, ) -> Self
Create a tool-call response turn.
Sourcepub fn request_error(message: impl Into<String>) -> Self
pub fn request_error(message: impl Into<String>) -> Self
Create a request-error response turn.
Sourcepub fn from_content(content: AssistantContent) -> Self
pub fn from_content(content: AssistantContent) -> Self
Create a response turn from one assistant content item.
Sourcepub fn from_contents(
content: impl IntoIterator<Item = AssistantContent>,
) -> Result<Self, EmptyListError>
pub fn from_contents( content: impl IntoIterator<Item = AssistantContent>, ) -> Result<Self, EmptyListError>
Create a response turn from multiple assistant content items.
Sourcepub fn with_call_id(self, call_id: impl Into<String>) -> Self
pub fn with_call_id(self, call_id: impl Into<String>) -> Self
Attach a provider-specific call ID to a tool-call response turn.
Sourcepub fn with_usage(self, usage: Usage) -> Self
pub fn with_usage(self, usage: Usage) -> Self
Override usage for this turn.
Sourcepub fn with_message_id(self, message_id: impl Into<String>) -> Self
pub fn with_message_id(self, message_id: impl Into<String>) -> Self
Set a provider-assigned assistant message ID for this turn.