pub struct ThinkTool;Expand description
The Think tool allows agents to stop and think in complex tool use situations.
This tool provides a dedicated space for structured thinking during complex tasks, particularly when processing external information (e.g., tool call results). It doesn’t actually perform any actions or retrieve any information - it just provides a space for the model to reason through complex problems.
This tool is original derived from the Think tool blog post from Anthropic.