pub trait ToolEmbeddingDyn: ToolDyn {
// Required methods
fn context(&self) -> Result<Value>;
fn embedding_docs(&self) -> Vec<String>;
}Expand description
Wrapper trait to allow for dynamic dispatch of raggable tools
Required Methods
Sourcefn embedding_docs(&self) -> Vec<String>
fn embedding_docs(&self) -> Vec<String>
Returns text fragments used to retrieve this tool from a vector store.