ToolEmbeddingDyn

Trait ToolEmbeddingDyn 

pub trait ToolEmbeddingDyn: ToolDyn {
    // Required methods
    fn context(&self) -> Result<Value>;
    fn embedding_docs(&self) -> Vec<String>;
}
Wrapper trait to allow for dynamic dispatch of raggable tools

Required Methods

fn context(&self) -> Result<Value>

Serializes context needed to reconstruct this dynamic tool.

fn embedding_docs(&self) -> Vec<String>

Returns text fragments used to retrieve this tool from a vector store.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> ToolEmbeddingDyn for T
where T: ToolEmbedding + 'static,