pub fn invalid_arguments_feedback(tool: &str, raw: &str) -> String
What the model reads when its call to tool sent raw, arguments that are not a JSON object: the tool never ran, and the model calls it again.
tool
raw